@@ -33,18 +33,10 @@
 
 #include "config.h"
 
+#include "gdkdisplay.h"
 #include "gdkinput.h"
-#include "gdkprivate.h"
 
-/* When ther necessary stuff is in
- * gdkinput.h, gdkinternals.h and
- * gdkprivate.h, these includes shouldn't be here.
- */
-
-#include <windows.h>
-#ifdef HAVE_WINTAB
-#include <wintab.h>
-#endif
+#include "gdkprivate-win32.h"
 #include "gdkinput-win32.h"
 
 static GdkDeviceAxis gdk_input_core_axes[] = {
@@ -54,38 +46,24 @@ static GdkDeviceAxis gdk_input_core_axes[] = {
 
 /* Global variables  */
 
-GDKVAR GdkDevice *_gdk_core_pointer = NULL;
- 
 gint              _gdk_input_ignore_core;
 
 GList            *_gdk_input_devices;
 GList            *_gdk_input_windows;
 
 void
-_gdk_init_input_core (void)
+_gdk_init_input_core (GdkDisplay *display)
 {
-  _gdk_core_pointer = g_object_new (GDK_TYPE_DEVICE, NULL);
+  display->core_pointer = g_object_new (GDK_TYPE_DEVICE, NULL);
   
-  _gdk_core_pointer->name = "Core Pointer";
-  _gdk_core_pointer->source = GDK_SOURCE_MOUSE;
-  _gdk_core_pointer->mode = GDK_MODE_SCREEN;
-  _gdk_core_pointer->has_cursor = TRUE;
-  _gdk_core_pointer->num_axes = 2;
-  _gdk_core_pointer->axes = gdk_input_core_axes;
-  _gdk_core_pointer->num_keys = 0;
-  _gdk_core_pointer->keys = NULL;
-}
-
-static void
-gdk_device_finalize (GObject *object)
-{
-  g_error ("A GdkDevice object was finalized. This should not happen");
-}
-
-static void
-gdk_device_class_init (GObjectClass *class)
-{
-  class->finalize = gdk_device_finalize;
+  display->core_pointer->name = "Core Pointer";
+  display->core_pointer->source = GDK_SOURCE_MOUSE;
+  display->core_pointer->mode = GDK_MODE_SCREEN;
+  display->core_pointer->has_cursor = TRUE;
+  display->core_pointer->num_axes = 2;
+  display->core_pointer->axes = gdk_input_core_axes;
+  display->core_pointer->num_keys = 0;
+  display->core_pointer->keys = NULL;
 }
 
 GType
@@ -96,20 +74,20 @@ gdk_device_get_type (void)
   if (!object_type)
     {
       static const GTypeInfo object_info =
-      {
-        sizeof (GdkDeviceClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) gdk_device_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GdkDevicePrivate),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) NULL,
-      };
+	{
+	  sizeof (GdkDeviceClass),
+	  (GBaseInitFunc) NULL,
+	  (GBaseFinalizeFunc) NULL,
+	  (GClassInitFunc) NULL,
+	  NULL,			/* class_finalize */
+	  NULL,			/* class_data */
+	  sizeof (GdkDevicePrivate),
+	  0,			/* n_preallocs */
+	  (GInstanceInitFunc) NULL,
+	};
       
       object_type = g_type_register_static (G_TYPE_OBJECT,
-                                            "GdkDevice",
+                                            g_intern_static_string ("GdkDevice"),
                                             &object_info, 0);
     }
   
@@ -119,6 +97,15 @@ gdk_device_get_type (void)
 GList *
 gdk_devices_list (void)
 {
+  return gdk_display_list_devices (_gdk_display);
+}
+
+GList *
+gdk_display_list_devices (GdkDisplay *dpy)
+{
+  g_return_val_if_fail (dpy == _gdk_display, NULL);
+
+  _gdk_input_wintab_init_check ();
   return _gdk_input_devices;
 }
 
@@ -186,8 +173,10 @@ gdk_device_get_history  (GdkDevice         *device,
   g_return_val_if_fail (events != NULL, FALSE);
   g_return_val_if_fail (n_events != NULL, FALSE);
 
-  *n_events = 0;
-  *events = NULL;
+  if (n_events)
+    *n_events = 0;
+  if (events)
+    *events = NULL;
 
   if (GDK_WINDOW_DESTROYED (window))
     return FALSE;
@@ -225,7 +214,7 @@ gdk_device_free_history (GdkTimeCoord **events,
 }
 
 GdkInputWindow *
-gdk_input_window_find(GdkWindow *window)
+_gdk_input_window_find(GdkWindow *window)
 {
   GList *tmp_list;
 
@@ -262,6 +251,8 @@ gdk_input_set_extension_events (GdkWindow *window, gint mask,
 
   if (mask != 0)
     {
+      _gdk_input_wintab_init_check ();
+
       iw = g_new(GdkInputWindow,1);
 
       iw->window = window;
@@ -282,7 +273,7 @@ gdk_input_set_extension_events (GdkWindow *window, gint mask,
     }
   else
     {
-      iw = gdk_input_window_find (window);
+      iw = _gdk_input_window_find (window);
       if (iw)
 	{
 	  _gdk_input_windows = g_list_remove(_gdk_input_windows,iw);
@@ -308,17 +299,45 @@ gdk_input_set_extension_events (GdkWindow *window, gint mask,
 }
 
 void
-gdk_input_window_destroy (GdkWindow *window)
+_gdk_input_window_destroy (GdkWindow *window)
 {
   GdkInputWindow *input_window;
 
-  input_window = gdk_input_window_find (window);
+  input_window = _gdk_input_window_find (window);
   g_return_if_fail (input_window != NULL);
 
   _gdk_input_windows = g_list_remove (_gdk_input_windows,input_window);
   g_free(input_window);
 }
 
+void
+_gdk_input_crossing_event (GdkWindow *window,
+			   gboolean enter)
+{
+  GdkWindowObject *priv = (GdkWindowObject *)window;
+  GdkInputWindow *input_window;
+  gint root_x, root_y;
+
+  if (enter)
+    {
+#if 0
+      /* No idea what to do... */
+#if 0
+      gdk_input_check_proximity(display);
+#endif
+      input_window = priv->input_window;
+      if (input_window != NULL)
+	{
+	  _gdk_input_get_root_relative_geometry (window, &root_x, &root_y);
+	  input_window->root_x = root_x;
+	  input_window->root_y = root_y;
+	}
+#endif
+    }
+  else
+    _gdk_input_ignore_core = FALSE;
+}
+
 void
 _gdk_input_exit (void)
 {
