@@ -25,76 +25,87 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#ifndef __GTK_LAYOUT_H
-#define __GTK_LAYOUT_H
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
+#ifndef __GTK_LAYOUT_H__
+#define __GTK_LAYOUT_H__
+
 
-#include <gdk/gdk.h>
 #include <gtk/gtkcontainer.h>
 #include <gtk/gtkadjustment.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
 
+G_BEGIN_DECLS
 
 #define GTK_TYPE_LAYOUT            (gtk_layout_get_type ())
-#define GTK_LAYOUT(obj)            (GTK_CHECK_CAST ((obj), GTK_TYPE_LAYOUT, GtkLayout))
-#define GTK_LAYOUT_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_LAYOUT, GtkLayoutClass))
-#define GTK_IS_LAYOUT(obj)         (GTK_CHECK_TYPE ((obj), GTK_TYPE_LAYOUT))
-#define GTK_IS_LAYOUT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_LAYOUT))
-#define GTK_LAYOUT_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_LAYOUT, GtkLayoutClass))
+#define GTK_LAYOUT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_LAYOUT, GtkLayout))
+#define GTK_LAYOUT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_LAYOUT, GtkLayoutClass))
+#define GTK_IS_LAYOUT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_LAYOUT))
+#define GTK_IS_LAYOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_LAYOUT))
+#define GTK_LAYOUT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_LAYOUT, GtkLayoutClass))
 
 
 typedef struct _GtkLayout        GtkLayout;
 typedef struct _GtkLayoutClass   GtkLayoutClass;
 
-struct _GtkLayout {
-  GtkContainer container;
+struct _GtkLayout
+{
+  GtkContainer GSEAL (container);
 
-  GList *children;
+  GList *GSEAL (children);
 
-  guint width;
-  guint height;
+  guint GSEAL (width);
+  guint GSEAL (height);
 
-  GtkAdjustment *hadjustment;
-  GtkAdjustment *vadjustment;
+  GtkAdjustment *GSEAL (hadjustment);
+  GtkAdjustment *GSEAL (vadjustment);
 
   /*< public >*/
-  GdkWindow *bin_window;
+  GdkWindow *GSEAL (bin_window);
 
   /*< private >*/
-  GdkVisibilityState visibility;
-  gint scroll_x;
-  gint scroll_y;
+  GdkVisibilityState GSEAL (visibility);
+  gint GSEAL (scroll_x);
+  gint GSEAL (scroll_y);
 
-  guint freeze_count;
+  guint GSEAL (freeze_count);
 };
 
-struct _GtkLayoutClass {
+struct _GtkLayoutClass
+{
   GtkContainerClass parent_class;
 
   void  (*set_scroll_adjustments)   (GtkLayout	    *layout,
 				     GtkAdjustment  *hadjustment,
 				     GtkAdjustment  *vadjustment);
+
+  /* Padding for future expansion */
+  void (*_gtk_reserved1) (void);
+  void (*_gtk_reserved2) (void);
+  void (*_gtk_reserved3) (void);
+  void (*_gtk_reserved4) (void);
 };
 
-GtkType        gtk_layout_get_type        (void) G_GNUC_CONST;
+GType          gtk_layout_get_type        (void) G_GNUC_CONST;
 GtkWidget*     gtk_layout_new             (GtkAdjustment *hadjustment,
 				           GtkAdjustment *vadjustment);
-void           gtk_layout_put             (GtkLayout     *layout, 
-		                           GtkWidget     *child_widget, 
-		                           gint           x, 
+GdkWindow*     gtk_layout_get_bin_window  (GtkLayout     *layout);
+void           gtk_layout_put             (GtkLayout     *layout,
+		                           GtkWidget     *child_widget,
+		                           gint           x,
 		                           gint           y);
-  
-void           gtk_layout_move            (GtkLayout     *layout, 
-		                           GtkWidget     *child_widget, 
-		                           gint           x, 
+
+void           gtk_layout_move            (GtkLayout     *layout,
+		                           GtkWidget     *child_widget,
+		                           gint           x,
 		                           gint           y);
-  
-void           gtk_layout_set_size        (GtkLayout     *layout, 
+
+void           gtk_layout_set_size        (GtkLayout     *layout,
 			                   guint          width,
 			                   guint          height);
 void           gtk_layout_get_size        (GtkLayout     *layout,
@@ -122,8 +133,6 @@ void           gtk_layout_freeze          (GtkLayout     *layout);
 void           gtk_layout_thaw            (GtkLayout     *layout);
 #endif /* GTK_DISABLE_DEPRECATED */
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
-#endif /* __GTK_LAYOUT_H */
+#endif /* __GTK_LAYOUT_H__ */
